==> tax-cherry-contract-model-1.0.2-20200403.015735-19-sources.jar: com/xforceplus/micro/tax/cherry/contract/model/vatv2/UnDistributeQueryMessage.java <==
package com.xforceplus.micro.tax.cherry.contract.model.vatv2;

import com.xforceplus.micro.tax.cherry.contract.model.vatv2.model.BaseResponseDto;
import com.xforceplus.micro.tax.cherry.contract.model.vatv2.model.terminal.TerminalDto;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.List;

public class UnDistributeQueryMessage {

    @Data
    public static class Request {

        /**
         * 终端服务器信息
         */
        private TerminalDto terminalDto;

        /**
         * 发票类型
         */
        private String invoiceType;
    }

    @Data
    @EqualsAndHashCode(callSuper = true)
    public static class Response extends BaseResponseDto {
        private Result result;

        @Data
        public static class Result {

            private List<UnDistribute> unDistributeList;

            @Data
            public static class UnDistribute {

                /**
                 * 发票代码
                 */
                private String invoiceCode;

                /**
                 * 起始号码
                 */
                private String startInvoiceNo;

                /**
                 * 终止号码
                 */
                private String endInvoiceNo;

                /**
                 * 发票份数
                 */
                private String invoiceCount;

                /**
                 * 领购日期
                 */
                private String purchaseDate;

                /**
                 * 领购人员
                 */
                private String operator;

                /**
                 * 其他信息
                 */
                private String otherMsg;
            }
        }
    }
}

==> tax-cherry-contract-model-1.0.8-20210818.070137-7-sources.jar: com/xforceplus/micro/tax/cherry/contract/model/vatv2/UnDistributeQueryMessage.java <==
package com.xforceplus.micro.tax.cherry.contract.model.vatv2;

import com.xforceplus.micro.tax.cherry.contract.model.vatv2.model.BaseResponseDto;
import com.xforceplus.micro.tax.cherry.contract.model.vatv2.model.device.DeviceDto;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.List;

public class UnDistributeQueryMessage {

    @Data
    public static class Request {

        /**
         * 设备服务器信息
         */
        private DeviceDto deviceDto;

        /**
         * 发票类型
         */
        private String invoiceType;
    }

    @Data
    @EqualsAndHashCode(callSuper = true)
    public static class Response extends BaseResponseDto {

        private Result result = new Result();

        @Data
        public static class Result {

            private List<UnDistribute> unDistributeList;

            @Data
            public static class UnDistribute {

                /**
                 * 发票代码
                 */
                private String invoiceCode;

                /**
                 * 起始号码
                 */
                private String startInvoiceNo;

                /**
                 * 终止号码
                 */
                private String endInvoiceNo;

                /**
                 * 发票份数
                 */
                private String invoiceCount;

                /**
                 * 剩余数量
                 */
                private String remainCount;

                /**
                 * 领购日期
                 */
                private String purchaseDate;

                /**
                 * 领购人员
                 */
                private String operator;

                /**
                 * 其他信息
                 */
                private String otherMsg;
            }
        }
    }
}
